@@ -2,6 +2,7 @@
 #'
 #' @description
 #' A tidytable object is simply a data.table with nice printing features.
+#' As such it can be used exactly like a data.table would be used.
 #'
 #' Note that all tidytable functions automatically convert data.frames & data.tables to tidytables in the background.
 #' As such this function will rarely need to be used by the user.
@@ -13,9 +14,6 @@
 #' @examples
 #' data.frame(x = 1:3) %>%
 #'   as_tidytable()
-#'
-#' data.frame(x = 1:3) %>%
-#'   as_dt()
 as_tidytable <- function(x) {
   UseMethod("as_tidytable")
 }
@@ -37,7 +35,11 @@ as_tidytable.default <- function(x) {
 
 #' @export
 #' @rdname as_tidytable
-as_dt <- as_tidytable
+as_dt <- function(x) {
+  deprecate_soft("0.5.5", "tidytable::as_dt()", "as_tidytable()")
+
+  as_tidytable(x)
+}
 
 # Add tidytable class to a data.table
 add_class <- function(.df) {
