@@ -1,9 +1,10 @@
-#' Case when
+#' Improved data.table::fcase()
 #'
 #' @description
 #' This function allows you to use multiple if/else statements in one call.
 #'
-#' Note that this function is called differently than `dplyr::case_when`. See examples.
+#' It is called like `data.table::fcase()`, but allows the user to use
+#' a vector as the `default` argument.
 #'
 #' @param ... Sequence of condition/value designations
 #' @param default Default value. Set to NA by default.
@@ -11,27 +12,21 @@
 #' @export
 #'
 #' @examples
-#' test_df <- tidytable(
-#'   a = 1:10,
-#'   b = 11:20,
-#'   c = c(rep("a", 6), rep("b", 4)),
-#'   d = c(rep("a", 4), rep("b", 6)))
+#' test_df <- tidytable(x = 1:10)
 #'
 #' test_df %>%
-#'   mutate.(x = case.(b < 13, 3,
-#'                     a > 4, 2,
-#'                     default = 10))
-#' test_df %>%
-#'   mutate.(x = case.(c == "a", "a",
-#'                     default = d))
+#'   mutate.(case_x = case.(x < 5, 1,
+#'                          x < 7, 2,
+#'                          default = 3))
 case. <- function(..., default = NA) {
   dots <- enquos(...)
   dots_length <- length(dots)
 
-  index <- '+'(1, 1:dots_length) %% 2
+  odd_index <- as.logical(seq_len(dots_length) %% 2)
+  even_index <- !odd_index
 
-  conditions <- dots[index == 0]
-  values <- dots[index == 1]
+  conditions <- dots[odd_index]
+  values <- dots[even_index]
 
   if (length(conditions) == 0) abort("No conditions supplied")
   if (length(values) == 0) abort("No values supplied")
@@ -55,7 +50,7 @@ case. <- function(..., default = NA) {
 #' @rdname dt_verb
 #' @inheritParams case.
 dt_case <- function(..., default = NA) {
-  deprecate_warn("0.5.2", "tidytable::dt_case()", "case.()")
+  deprecate_stop("0.5.2", "tidytable::dt_case()", "case.()")
 
   case.(..., default = default)
 }
