@@ -12,7 +12,6 @@
 #' `{.col}` stands for the selected column, and `{.fn}` stands for the name of the function being applied.
 #' The default (`NULL`) is equivalent to `"{.col}"` for a single function case and `"{.col}_{.fn}"`
 #' when a list is used for `.fns`.
-#' @param by This argument has been renamed to .by and is deprecated
 #'
 #' @export
 #'
@@ -39,21 +38,20 @@
 #'                  .fns = list(new = ~ .x * 2, another = ~ .x + 7),
 #'                  .names = "{.col}_test_{.fn}")
 mutate_across. <- function(.df, .cols = everything(), .fns, ...,
-                           .by = NULL, .names = NULL, by = NULL) {
+                           .by = NULL, .names = NULL) {
   UseMethod("mutate_across.")
 }
 
 #' @export
 mutate_across..data.frame <- function(.df, .cols = everything(), .fns, ...,
-                                      .by = NULL, .names = NULL, by = NULL) {
+                                      .by = NULL, .names = NULL) {
 
   .df <- as_tidytable(.df)
   .df <- shallow(.df)
 
   .cols <- select_vec_chr(.df, {{ .cols }})
 
-  .by <- check_dot_by(enquo(.by), enquo(by), "mutate_across.")
-  .by <- select_vec_chr(.df, !!.by)
+  .by <- select_vec_chr(.df, {{ .by }})
 
   .cols <- .cols[.cols %notin% .by]
 
@@ -108,9 +106,8 @@ mutate_across..data.frame <- function(.df, .cols = everything(), .fns, ...,
 #' @export
 #' @rdname dt_verb
 #' @inheritParams mutate_across.
-dt_mutate_across <- function(.df, .cols = everything(), .fns, ..., .by = NULL, by = NULL) {
-  deprecate_warn("0.5.2", "tidytable::dt_mutate_across()", "mutate_across.()")
+dt_mutate_across <- function(.df, .cols = everything(), .fns, ..., .by = NULL) {
+  deprecate_stop("0.5.2", "tidytable::dt_mutate_across()", "mutate_across.()")
 
-  .by <- check_dot_by(enquo(.by), enquo(by))
   mutate_across.(.df, .cols = {{ .cols }}, .fns, ..., .by = {{ .by }})
 }
