@@ -46,7 +46,7 @@ pull..data.frame <- function(.df, var = -1) {
 #' @rdname dt_verb
 #' @inheritParams pull.
 dt_pull <- function(.df, var = -1) {
-  deprecate_warn("0.5.2", "tidytable::dt_pull()", "pull.()")
+  deprecate_stop("0.5.2", "tidytable::dt_pull()", "pull.()")
 
   pull.(.df, var = {{ var }})
 }
