@@ -72,7 +72,7 @@ relocate..data.frame <- function(.df, ..., .before = NULL, .after = NULL) {
 #' @rdname dt_verb
 #' @inheritParams relocate.
 dt_relocate <- function(.df, ..., .before = NULL, .after = NULL) {
-  deprecate_warn("0.5.2", "tidytable::dt_relocate()", "relocate.()")
+  deprecate_stop("0.5.2", "tidytable::dt_relocate()", "relocate.()")
 
   relocate.(.df, ..., .before = {{ .before }}, .after = {{ .after }})
 }
