@@ -8,7 +8,6 @@
 #' @param order_by Variable to arrange by
 #' @param n Number of rows to grab
 #' @param .by Columns to group by
-#' @param by This argument has been renamed to .by and is deprecated
 #'
 #' @export
 #'
@@ -38,12 +37,12 @@
 #'
 #' test_df %>%
 #'   slice_min.(order_by = y, .by = z)
-slice. <- function(.df, ..., .by = NULL, by = NULL) {
+slice. <- function(.df, ..., .by = NULL) {
   UseMethod("slice.")
 }
 
 #' @export
-slice..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
+slice..data.frame <- function(.df, ..., .by = NULL) {
 
   .df <- as_tidytable(.df)
 
@@ -53,13 +52,13 @@ slice..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
 
   data_env <- env(quo_get_env(rows[[1]]), .df = .df)
 
-  .by <- check_dot_by(enquo(.by), enquo(by), "slice.")
+  .by <- enquo(.by)
 
   by_is_null <- quo_is_null(.by)
 
   if (by_is_null) {
     .df <- eval_quo(
-      .df[1:.N %in% c(!!!rows)],
+      .df[{.rows = c(!!!rows); .rows = .rows[data.table::between(.rows, -.N, .N)]; .rows}],
       new_data_mask(data_env), env = caller_env()
     )
   } else {
@@ -69,7 +68,9 @@ slice..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
     .by <- select_vec_chr(.df, !!.by)
 
     .df <- eval_quo(
-      .df[, .SD[1:.N %in% c(!!!rows)], by = !!.by],
+      .df[,
+          .SD[{.rows = c(!!!rows); .rows = .rows[data.table::between(.rows, -.N, .N)]; .rows}],
+          by = !!.by],
       new_data_mask(data_env), env = caller_env()
     )
 
@@ -82,12 +83,12 @@ slice..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
 
 #' @export
 #' @rdname slice.
-slice_head. <- function(.df, n = 5, .by = NULL, by = NULL) {
+slice_head. <- function(.df, n = 5, .by = NULL) {
   UseMethod("slice_head.")
 }
 
 #' @export
-slice_head..data.frame <- function(.df, n = 5, .by = NULL, by = NULL) {
+slice_head..data.frame <- function(.df, n = 5, .by = NULL) {
 
   .df <- as_tidytable(.df)
 
@@ -95,8 +96,7 @@ slice_head..data.frame <- function(.df, n = 5, .by = NULL, by = NULL) {
 
   data_env <- env(quo_get_env(n), .df = .df)
 
-  .by <- check_dot_by(enquo(.by), enquo(by), "slice_head.")
-  .by <- select_vec_chr(.df, !!.by)
+  .by <- select_vec_chr(.df, {{ .by }})
 
   if (length(.by) > 0) col_order <- names(.df)
 
@@ -113,12 +113,12 @@ slice_head..data.frame <- function(.df, n = 5, .by = NULL, by = NULL) {
 
 #' @export
 #' @rdname slice.
-slice_tail. <- function(.df, n = 5, .by = NULL, by = NULL) {
+slice_tail. <- function(.df, n = 5, .by = NULL) {
   UseMethod("slice_tail.")
 }
 
 #' @export
-slice_tail..data.frame <- function(.df, n = 5, .by = NULL, by = NULL) {
+slice_tail..data.frame <- function(.df, n = 5, .by = NULL) {
 
   .df <- as_tidytable(.df)
 
@@ -126,8 +126,7 @@ slice_tail..data.frame <- function(.df, n = 5, .by = NULL, by = NULL) {
 
   data_env <- env(quo_get_env(n), .df = .df)
 
-  .by <- check_dot_by(enquo(.by), enquo(by), "slice_tail.")
-  .by <- select_vec_chr(.df, !!.by)
+  .by <- select_vec_chr(.df, {{ .by }})
 
   if (length(.by) > 0) col_order <- names(.df)
 
@@ -143,98 +142,84 @@ slice_tail..data.frame <- function(.df, n = 5, .by = NULL, by = NULL) {
 
 #' @export
 #' @rdname slice.
-slice_max. <- function(.df, order_by, n = 1, .by = NULL, by = NULL) {
+slice_max. <- function(.df, order_by, n = 1, .by = NULL) {
   UseMethod("slice_max.")
 }
 
 #' @export
-slice_max..data.frame <- function(.df, order_by, n = 1, .by = NULL, by = NULL) {
+slice_max..data.frame <- function(.df, order_by, n = 1, .by = NULL) {
 
   .df <- as_tidytable(.df)
 
   if (missing(order_by)) stop("order_by must be supplied")
 
-  .by <- check_dot_by(enquo(.by), enquo(by), "slice_max.")
-
   .df %>%
     arrange.(-{{ order_by }}) %>%
-    slice_head.(n, .by = !!.by)
+    slice_head.(n, .by = {{ .by }})
 }
 
 #' @export
 #' @rdname slice.
-slice_min. <- function(.df, order_by, n = 1, .by = NULL, by = NULL) {
+slice_min. <- function(.df, order_by, n = 1, .by = NULL) {
   UseMethod("slice_min.")
 }
 
 #' @export
-slice_min..data.frame <- function(.df, order_by, n = 1, .by = NULL, by = NULL) {
+slice_min..data.frame <- function(.df, order_by, n = 1, .by = NULL) {
 
   .df <- as_tidytable(.df)
 
   if (missing(order_by)) stop("order_by must be supplied")
 
-  .by <- check_dot_by(enquo(.by), enquo(by), "slice_min.")
-
   .df %>%
     arrange.({{ order_by }}) %>%
-    slice_head.(n, .by = !!.by)
+    slice_head.(n, .by = {{ .by }})
 }
 
 #' @export
 #' @rdname dt_verb
 #' @inheritParams slice.
-dt_slice <- function(.df, ..., .by = NULL, by = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_slice()", "slice.()")
+dt_slice <- function(.df, ..., .by = NULL) {
+  deprecate_stop("0.5.2", "tidytable::dt_slice()", "slice.()")
 
-  .by <- check_dot_by(enquo(.by), enquo(by))
-
-  slice.(.df, ..., .by = !!.by)
+  slice.(.df, ..., .by = {{ .by }})
 }
 
 #' @export
 #' @rdname dt_verb
 #' @inheritParams slice_head.
-dt_slice_head <- function(.df, n = 5, .by = NULL, by = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_slice_head()", "slice_head.()")
+dt_slice_head <- function(.df, n = 5, .by = NULL) {
+  deprecate_stop("0.5.2", "tidytable::dt_slice_head()", "slice_head.()")
 
-  .by <- check_dot_by(enquo(.by), enquo(by))
-
-  slice_head.(.df, n, .by = !!.by)
+  slice_head.(.df, n, .by = {{ .by }})
 }
 
 #' @export
 #' @rdname dt_verb
 #' @inheritParams slice_tail.
-dt_slice_tail <- function(.df, n = 5, .by = NULL, by = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_slice_tail()", "slice_tail.()")
+dt_slice_tail <- function(.df, n = 5, .by = NULL) {
+  deprecate_stop("0.5.2", "tidytable::dt_slice_tail()", "slice_tail.()")
 
-  .by <- check_dot_by(enquo(.by), enquo(by))
-
-  slice_tail.(.df, n, .by = !!.by)
+  slice_tail.(.df, n, .by = {{ .by }})
 }
 
 #' @export
 #' @rdname dt_verb
 #' @inheritParams slice_min.
-dt_slice_min <- function(.df, order_by, n = 1, .by = NULL, by = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_slice_min()", "slice_min.()")
+dt_slice_min <- function(.df, order_by, n = 1, .by = NULL) {
+  deprecate_stop("0.5.2", "tidytable::dt_slice_min()", "slice_min.()")
 
-  .by <- check_dot_by(enquo(.by), enquo(by))
-
-  slice_min.(.df, order_by = {{ order_by }}, n = n, .by = !!.by)
+  slice_min.(.df, order_by = {{ order_by }}, n = n, .by = {{ .by }})
 }
 
 
 #' @export
 #' @rdname dt_verb
 #' @inheritParams slice_max.
-dt_slice_max <- function(.df, order_by, n = 1, .by = NULL, by = NULL) {
-  deprecate_soft("0.5.2", "tidytable::dt_slice_max()", "slice_max.()")
+dt_slice_max <- function(.df, order_by, n = 1, .by = NULL) {
+  deprecate_stop("0.5.2", "tidytable::dt_slice_max()", "slice_max.()")
 
-  .by <- check_dot_by(enquo(.by), enquo(by))
-
-  slice_max.(.df, order_by = {{ order_by }}, n = n, .by = !!.by)
+  slice_max.(.df, order_by = {{ order_by }}, n = n, .by = {{ .by }})
 }
 
 
