@@ -6,7 +6,6 @@
 #' @param .df A data.frame or data.table
 #' @param ... Columns to create/modify
 #' @param .by Columns to group by
-#' @param by This argument has been renamed to .by and is deprecated
 #'
 #' @md
 #' @examples
@@ -14,18 +13,18 @@
 #'   transmute.(displ_l = disp / 61.0237)
 #'
 #' @export
-transmute. <- function(.df, ..., .by = NULL, by = NULL) {
+transmute. <- function(.df, ..., .by = NULL) {
   UseMethod("transmute.")
 }
 
 #' @export
-transmute..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
+transmute..data.frame <- function(.df, ..., .by = NULL) {
 
   .df <- as_tidytable(.df)
 
   dots <- enquos(...)
 
-  .by <- check_dot_by(enquo(.by), enquo(by), "transmute.")
+  .by <- enquo(.by)
 
   .df <- mutate.(.df, ..., .by = !!.by)
 
@@ -39,12 +38,11 @@ transmute..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
 #' @export
 #' @rdname dt_verb
 #' @inheritParams transmute.
-dt_transmute <- function(.df, ..., .by = NULL, by = NULL) {
-  deprecate_warn("0.5.2", "tidytable::dt_transmute()", "transmute.()")
+dt_transmute <- function(.df, ..., .by = NULL) {
+  deprecate_stop("0.5.2", "tidytable::dt_transmute()", "transmute.()")
 
-  .by <- check_dot_by(enquo(.by), enquo(by))
 
-  transmute.(.df, ..., .by = !!.by)
+  transmute.(.df, ..., .by = {{ .by }})
 }
 
 
