@@ -7,19 +7,6 @@ eval_quo <- function(express, data = NULL, env = caller_env()) {
   eval_tidy(quo_squash(enquo(express)), data = data, env = env)
 }
 
-check_dot_by <- function(.by, by, fn) {
-  if (!quo_is_null(by)) {
-
-    if (!missing(fn))
-      deprecate_warn("0.5.2", str_c.("tidytable::", fn, "(by = )"), str_c.(fn, "(.by = )"))
-
-    by
-
-  } else {
-    .by
-  }
-}
-
 # Creates a shallow copy to prevent modify-by-reference
 shallow <- function(x, cols = names(x), reset_class = FALSE) {
   stopifnot(is.data.table(x), all(cols %in% names(x)))
