@@ -1,14 +1,3 @@
-test_that("dt_ can add multiple columns & is deprecated", {
-  df <- data.table(x = 1:3, y = 1:3)
-  df <- df %>%
-    dt_mutate(double_x = x * 2,
-              double_y = y * 2)
-
-  expect_deprecated(dt_mutate(df, double_x = x * 2))
-  expect_named(df, c("x", "y", "double_x", "double_y"))
-  expect_equal(df$x * 2, df$double_x)
-})
-
 test_that("can remove variables with NULL", {
   df <- data.table(x = 1:3, y = 1:3)
   tidytable_df <- df %>% mutate.(y = NULL)
