@@ -1,15 +1,5 @@
 setup(options(lifecycle_verbosity = "quiet"))
 
-test_that("dt_mutate_across(): .cols works with is.numeric & is deprecated", {
-  df <- data.table(x_start = c(1,1,1), end_x = c(2,2,2), z = c("a", "a", "b"))
-  df <- df %>%
-    dt_mutate_across(where(is.numeric), function(.x) .x + 1)
-
-  expect_deprecated(dt_mutate_across(df, where(is.numeric), function(.x) .x + 1))
-  expect_equal(df$x_start, c(2,2,2))
-  expect_equal(df$end_x, c(3,3,3))
-})
-
 test_that("mutate_if() works for numeric columns", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
@@ -221,7 +211,7 @@ test_that("mutate_across.() works with twiddle", {
     mutate_across.(c(x:y), function(.x) .x + 1)
 
   twiddle_df <- df %>%
-    dt_mutate_across(c(x:y), ~ .x + 1)
+    mutate_across.(c(x:y), ~ .x + 1)
 
   expect_equal(anon_df, twiddle_df)
 })
