@@ -1,13 +1,3 @@
-test_that("dt_slice() works without .by", {
-  test_df <- tidytable(x = c(1,2,3,4), y = c(4,5,6,7), z = c("a", "a", "a", "b"))
-
-  sliced_df <- test_df %>%
-    dt_slice(1:4)
-
-  expect_deprecated(dt_slice(test_df, 1:4))
-  expect_equal(sliced_df, head(test_df, 4))
-})
-
 test_that("works without .by", {
   test_df <- tidytable(x = c(1,2,3,4), y = c(4,5,6,7), z = c("a", "a", "a", "b"))
 
@@ -83,6 +73,14 @@ test_that("works without .by with data.frame", {
   expect_equal(sliced_df, head(as_tidytable(test_df), 4))
 })
 
+test_that("negative numbers drop rows", {
+  test_df <- data.frame(x = c(1,2,3,4), y = c(4,5,6,7), z = c("a", "a", "a", "b"))
+  sliced_df <- test_df %>%
+    slice.(-3, -4)
+
+  expect_equal(sliced_df, head(as_tidytable(test_df), 2))
+})
+
 test_that("works with .by", {
   test_df <- tidytable(x = c(1,2,3,4), y = c(4,5,6,7), z = c("a", "a", "a", "b"))
   sliced_df <- test_df %>%
@@ -143,14 +141,6 @@ test_that("works in custom function", {
 
 # slice_head.() ----------------------------------------------------
 
-test_that("dt_slice_head() works when empty", {
-  test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
-  sliced_df <- test_df %>%
-    dt_slice_head()
-
-  expect_equal(sliced_df, head(test_df, 5))
-})
-
 test_that("_head.() works when empty", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
   sliced_df <- test_df %>%
@@ -205,14 +195,6 @@ test_that("_head.() works in custom function", {
 
 # slice_tail.() ----------------------------------------------------
 
-test_that("dt_slice_tail() works when empty", {
-  test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
-  sliced_df <- test_df %>%
-    dt_slice_tail()
-
-  expect_equal(sliced_df, tail(test_df, 5))
-})
-
 test_that("_tail.() works when empty", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
   sliced_df <- test_df %>%
@@ -267,15 +249,6 @@ test_that("_tail.() works with a custom function", {
 
 # slice_min.() ----------------------------------------------------
 
-test_that("dt_slice_min() works", {
-  test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
-  sliced_df <- test_df %>%
-    dt_slice_min(order_by = y, n = 3)
-
-  expect_equal(sliced_df$x, c(10,9,8))
-  expect_equal(sliced_df$y, c(11,12,13))
-})
-
 test_that("_min.() works", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
   sliced_df <- test_df %>%
