@@ -1,26 +1,10 @@
-test_that("dt_ unnesting works with nested data.table", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
-
-  nest_df <- start_df %>%
-    dt_group_nest(c, d)
-
-  unnest_df <- nest_df %>%
-    dt_unnest_legacy(data)
-
-  expect_named(unnest_df, c("c","d","a","b"))
-  expect_equal(unnest_df$a, start_df$a)
-})
+start_df <- tidytable(
+  a = 1:5,
+  b = 11:15,
+  c = c(rep("a", 3), rep("b", 2)),
+  d = c(rep("a", 2), rep("b", 3)))
 
 test_that("unnesting works with nested data.table", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
     nest_by.(c, d)
@@ -32,12 +16,19 @@ test_that("unnesting works with nested data.table", {
   expect_equal(unnest_df$a, start_df$a)
 })
 
+test_that("names_sep works", {
+
+  nest_df <- start_df %>%
+    nest_by.(c, d)
+
+  unnest_df <- nest_df %>%
+    unnest.(data, names_sep = "_")
+
+  expect_named(unnest_df, c("c","d","data_a","data_b"))
+  expect_equal(unnest_df$data_a, start_df$a)
+})
+
 test_that("unnesting works with multiple columns", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
     nest_by.(c, d) %>%
@@ -52,11 +43,6 @@ test_that("unnesting works with multiple columns", {
 })
 
 test_that("automatically unnests all list_cols", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
     nest_by.(c, d) %>%
@@ -71,11 +57,6 @@ test_that("automatically unnests all list_cols", {
 })
 
 test_that("unnesting works with nested vector", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
     nest_by.(c, d) %>%
@@ -90,11 +71,6 @@ test_that("unnesting works with nested vector", {
 })
 
 test_that("unnesting works with nested data.frames", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
     nest_by.(c, d) %>%
@@ -108,11 +84,6 @@ test_that("unnesting works with nested data.frames", {
 })
 
 test_that("unnesting works with nested matrices", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
     nest_by.(c, d) %>%
@@ -140,11 +111,6 @@ test_that("unnesting works with different ordered/different # of columns", {
 })
 
 test_that("unnesting works with nested data.table with quosure function", {
-  start_df <- data.table::data.table(
-    a = 1:5,
-    b = 11:15,
-    c = c(rep("a", 3), rep("b", 2)),
-    d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
     nest_by.(c, d)
@@ -168,7 +134,7 @@ test_that("unnesting works with nested data.table with quosure function", {
     mutate.(z = y)
 
   result_df <- test_df %>%
-    unnest.(y, .keep_all = TRUE)
+    unnest.(y, .drop = FALSE)
 
   expect_named(result_df, c("x","z","test"))
   expect_true(is.list(result_df$z))
